@@ -138,6 +138,10 @@ class Team(Model):
             slugify_instance(self, self.name, reserved=RESERVED_TEAM_SLUGS)
         super(Team, self).save(*args, **kwargs)
 
+    def get_absolute_url(self):
+        return absolute_uri(reverse('sentry', args=[
+            self.slug]))
+
     def get_owner_name(self):
         if not self.owner:
             return None
@@ -254,6 +258,10 @@ class Project(Model):
                     has_results = True
         super(Project, self).delete()
 
+    def get_absolute_url(self):
+        return absolute_uri(reverse('sentry-stream', args=[
+            self.team.slug, self.slug]))
+
     def merge_to(self, project):
         if not isinstance(project, Project):
             project = Project.objects.get_from_cache(pk=project)
