@@ -76,7 +76,9 @@
                 }
                 if (existing.get(i) === undefined) {
                     $('<a style="width:' + point_width + ';" rel="tooltip" title="' + title + '"><span style="height:' + pct + '">' + point.y + '</span></a>').tooltip({
-                        placement: options.placement || 'bottom'
+                        placement: options.placement || 'bottom',
+                        html: true,
+                        container: 'body'
                     }).appendTo($el);
                 } else {
                     $(existing[i]).find('span').css('height', pct).text(point.y).attr('title', (point.label || point.y));
@@ -85,4 +87,4 @@
         }
 
     };
-}(app, Backbone, jQuery));
\ No newline at end of file
+}(app, Backbone, jQuery));
